@@ -24,7 +24,7 @@ import Data.Convertible (Convertible (..), ConvertResult, ConvertError (..))
 import Data.PostgreSQL.NetworkAddress (NetAddress, Inet (..), Cidr (..))
 import Database.HDBC (SqlValue (..))
 import Database.HDBC.Record.Persistable ()
-import Database.Relational (ShowConstantTermsSQL (..))
+import Database.Relational (LiteralSQL (..))
 import Database.PostgreSQL.Parser (evalParser)
 import qualified Database.PostgreSQL.Parser as Parser
 import Database.PostgreSQL.Printer (execPrinter)
@@ -74,8 +74,8 @@ instance Convertible Cidr SqlValue where
 qstringNetAddr :: IsString s => NetAddress -> s
 qstringNetAddr = fromString . ("'" ++) . (++ "'") . execPrinter Printer.netAddress
 
-instance ShowConstantTermsSQL Inet where
-  showConstantTermsSQL' (Inet na) = pure $ "INET" <> qstringNetAddr na
+instance LiteralSQL Inet where
+  showLiteral' (Inet na) = pure $ "INET" <> qstringNetAddr na
 
-instance ShowConstantTermsSQL Cidr where
-  showConstantTermsSQL' (Cidr na) = pure $ "CIDR" <> qstringNetAddr na
+instance LiteralSQL Cidr where
+  showLiteral' (Cidr na) = pure $ "CIDR" <> qstringNetAddr na
